@@ -1,30 +1,59 @@
-from typing import Union, List
-
-from mypy.nodes import TypeInfo
+from __future__ import annotations
 
 from mypy.erasetype import erase_typevars
-from mypy.types import Instance, TypeVarType, TupleType, Type, TypeOfAny, AnyType, ParamSpecType
+from mypy.nodes import TypeInfo
+from mypy.types import (
+    AnyType,
+    Instance,
+    ParamSpecType,
+    TupleType,
+    Type,
+    TypeOfAny,
+    TypeVarLikeType,
+    TypeVarTupleType,
+    TypeVarType,
+    UnpackType,
+)
 
 
-def fill_typevars(typ: TypeInfo) -> Union[Instance, TupleType]:
+def fill_typevars(typ: TypeInfo) -> Instance | TupleType:
     """For a non-generic type, return instance type representing the type.
 
     For a generic G type with parameters T1, .., Tn, return G[T1, ..., Tn].
     """
-    tvs: List[Type] = []
+    tvs: list[Type] = []
     # TODO: why do we need to keep both typ.type_vars and typ.defn.type_vars?
     for i in range(len(typ.defn.type_vars)):
-        tv = typ.defn.type_vars[i]
+        tv: TypeVarLikeType | UnpackType = typ.defn.type_vars[i]
         # Change the line number
         if isinstance(tv, TypeVarType):
             tv = TypeVarType(
-                tv.name, tv.fullname, tv.id, tv.values,
-                tv.upper_bound, tv.variance, line=-1, column=-1,
+                tv.name,
+                tv.fullname,
+                tv.id,
+                tv.values,
+                tv.upper_bound,
+                tv.variance,
+                line=-1,
+                column=-1,
+            )
+        elif isinstance(tv, TypeVarTupleType):
+            tv = UnpackType(
+                TypeVarTupleType(
+                    tv.name,
+                    tv.fullname,
+                    tv.id,
+                    tv.upper_bound,
+                    tv.tuple_fallback,
+                    line=-1,
+                    column=-1,
+                )
             )
         else:
             assert isinstance(tv, ParamSpecType)
-            tv = ParamSpecType(tv.name, tv.fullname, tv.id, tv.flavor, tv.upper_bound,
-                               line=-1, column=-1)
+            tv = ParamSpecType(
+                tv.name, tv.fullname, tv.id, tv.flavor, tv.upper_bound, line=-1, column=-1
+            )
         tvs.append(tv)
     inst = Instance(typ, tvs)
     if typ.tuple_type is None:
@@ -32,7 +61,7 @@ def fill_typevars(typ: TypeInfo) -> Union[Instance, TupleType]:
     return typ.tuple_type.copy_modified(fallback=inst)
 
 
-def fill_typevars_with_any(typ: TypeInfo) -> Union[Instance, TupleType]:
+def fill_typevars_with_any(typ: TypeInfo) -> Instance | TupleType:
     """Apply a correct number of Any's as type arguments to a type."""
     inst = Instance(typ, [AnyType(TypeOfAny.special_form)] * len(typ.defn.type_vars))
     if typ.tuple_type is None:
